"use strict";
// --- private functions
Object.defineProperty(exports, "__esModule", { value: true });
var lad_api_utils_1 = require("./api/lad-api-utils");
var index_1 = require("./index");
function findModelEntry(target) {
    var found = null;
    for (var _i = 0, _a = index_1.LAD_GLOBAL.registeredModules; _i < _a.length; _i++) {
        var m = _a[_i];
        if (target instanceof m.model || target.MODEL_NAME === m.model.MODEL_NAME) {
            found = m;
            break;
        }
    }
    if (!found) { // todo: make sure system document
        found = new lad_api_utils_1.DocumentModuleEntry(target);
        index_1.LAD_GLOBAL.registeredModules.push(found);
    }
    return found;
}
// DECORATORS SECTION
// for automatically creating server side APIs
function API(type, roles) {
    return function (target, propertyKey, descriptor) {
        try {
            var m = findModelEntry(target);
            if (!m) {
                return;
            }
            var apiFn = {
                name: propertyKey,
                type: type,
                value: descriptor.value,
                roles: roles
            };
            m.api.push(apiFn);
            if (index_1.LAD_GLOBAL.registrar) {
                index_1.LAD_GLOBAL.registrar(m, apiFn);
            }
            console.log("Done registering API: " + target.name + " " + propertyKey);
        }
        catch (e) {
            console.warn(e.message);
        }
    };
}
exports.API = API;
// for automatically indexing fields to mongodb
function Index(target, propertyKey) {
    try {
        var modelName = target.constructor.MODEL_NAME;
        if (index_1.LAD_GLOBAL.indexedFieldsRegistrar) {
            index_1.LAD_GLOBAL.indexedFieldsRegistrar(modelName, propertyKey);
        }
        index_1.LAD_GLOBAL.indexedFieldsRegistry[modelName + "." + propertyKey] = { propertyKey: propertyKey, modelName: modelName };
    }
    catch (e) {
        console.warn(e.message);
    }
}
exports.Index = Index;
// SSE events (public router)
function PublicEvent(target, propertyKey) {
    try {
        var modelName = target.MODEL_NAME;
        var eventName = target[propertyKey];
        var channelName = modelName + "/" + eventName;
        if (index_1.LAD_GLOBAL.publicServerEventsRegistrar) {
            index_1.LAD_GLOBAL.publicServerEventsRegistrar(channelName);
        }
        else {
            index_1.LAD_GLOBAL.publicServerEventsRegistry.add(channelName);
        }
    }
    catch (e) {
        console.warn(e.message);
    }
}
exports.PublicEvent = PublicEvent;
//# sourceMappingURL=decorators.js.map