"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var uuid_1 = require("uuid");
var lad_date_1 = require("./lad-date");
var SystemHeader = /** @class */ (function () {
    function SystemHeader(type, systemId) {
        this.type = type;
        this.systemId = systemId;
        // the server is responsible for removing this flag upon saving
        this.isNew = true;
        this.createdOnLadDate = new lad_date_1.LadDate();
        // update
        this.updatedOnLadDate = this.createdOnLadDate;
        this.versionId = uuid_1.v4();
        this.currentVersion = true;
        if (!systemId) {
            this.systemId = 'default';
        }
    }
    return SystemHeader;
}());
exports.SystemHeader = SystemHeader;
exports.MONGODB_DOLLAR_UPDATE_OPERATIONS = [
    // Update Operations
    "$currentDate",
    "$inc",
    "$min",
    "$max",
    "$mul",
    "$rename",
    "$set",
    "$setOnInsert",
    "$unset",
    "$addToSet",
    "$pop",
    "$pull",
    "$push",
    "$pullAll",
    "$each",
    "$slice",
    "$sort",
    "$position",
    "$bit",
    "$isolated"
];
var SystemDocument = /** @class */ (function () {
    function SystemDocument(type, systemId) {
        this.documentId = uuid_1.v4();
        this.systemHeader = new SystemHeader(type, systemId);
    }
    SystemDocument.__archiveDocument = function (original, now, updaterId) {
        // create the expired version by setting currentVersion = false; this will be inserted as an older version
        var expired = Object.assign({}, original);
        // remove _id so it will not conflict with an existing record on insert
        if (expired._id) {
            delete expired._id;
        }
        // archive this version
        expired.systemHeader.currentVersion = false;
        expired.systemHeader.archiveInfo = {
            archivedBy: updaterId,
            archivedOn: now
        };
        return expired;
    };
    SystemDocument.__getDeleteUpdateInfo = function (deleterId) {
        var deleteUpdates = {};
        deleteUpdates['systemHeader.deleteInfo'] = {
            deletedBy: deleterId,
            deletedOn: new lad_date_1.LadDate()
        };
        deleteUpdates['systemHeader.deleted'] = true;
        return { $set: deleteUpdates };
    };
    SystemDocument.__getUpdateInfo = function (original, updatedDocumentOrig, updaterId) {
        // do not mutate original updatedDocument
        var updatedDocument = Object.assign({}, updatedDocumentOrig);
        // never allow these to be updated
        delete updatedDocument.documentId;
        delete updatedDocument.systemHeader;
        var now = new lad_date_1.LadDate();
        var archived = SystemDocument.__archiveDocument(original, now, updaterId);
        updatedDocument['systemHeader.previousVersion'] = archived.systemHeader.versionId;
        updatedDocument['systemHeader.versionId'] = uuid_1.v4();
        updatedDocument['systemHeader.updatedOnLadDate'] = now;
        updatedDocument['systemHeader.updatedBy'] = updaterId;
        // update info to be sent into mongodb
        var updateInfo = {};
        var keys = Object.keys(updatedDocument);
        for (var _i = 0, keys_1 = keys; _i < keys_1.length; _i++) {
            var k = keys_1[_i];
            if (exports.MONGODB_DOLLAR_UPDATE_OPERATIONS.indexOf(k) > -1) {
                updateInfo[k] = updatedDocument[k];
                delete updatedDocument[k];
            }
        }
        if (updateInfo.$set) {
            updateInfo.$set = Object.assign(updateInfo.$set, updatedDocument);
        }
        else {
            updateInfo.$set = updatedDocument;
        }
        return { archived: archived, updateInfo: updateInfo };
    };
    return SystemDocument;
}());
exports.SystemDocument = SystemDocument;
//# sourceMappingURL=system-document.model.js.map